
:tocdepth: 1

.. _sdsswork:

SDSSWORK
--------

This is the default configuration loaded.  It defines the current set of environment variables.

.. datamodel:: tree.tree:Tree
   :prog: sdsswork
   :title: sdsswork
   :remove-sasbase:

.. _dr16:

DR16
--------

This is the configuration for data release 16

.. datamodel:: tree.tree:Tree
   :prog: dr16
   :title: dr16
   :remove-sasbase:

.. _dr15:

DR15
--------

This is the configuration for data release 15

.. datamodel:: tree.tree:Tree
   :prog: dr15
   :title: dr15
   :remove-sasbase:

.. _dr14:

DR14
--------

This is the configuration for data release 14

.. datamodel:: tree.tree:Tree
   :prog: dr14
   :title: dr14
   :remove-sasbase:

.. _dr13:

DR13
--------

This is the configuration for data release 13

.. datamodel:: tree.tree:Tree
   :prog: dr13
   :title: dr13
   :remove-sasbase:

.. _dr12:

DR12
--------

This is the configuration for data release 12

.. datamodel:: tree.tree:Tree
   :prog: dr12
   :title: dr12
   :remove-sasbase:

.. _dr11:

DR11
--------

This is the configuration for data release 11

.. datamodel:: tree.tree:Tree
   :prog: dr11
   :title: dr11
   :remove-sasbase:

.. _dr10:

DR10
--------

This is the configuration for data release 10

.. datamodel:: tree.tree:Tree
   :prog: dr10
   :title: dr10
   :remove-sasbase:

.. _dr9:

DR9
--------

This is the configuration for data release 9

.. datamodel:: tree.tree:Tree
   :prog: dr9
   :title: dr9
   :remove-sasbase:

.. _dr8:

DR8
--------

This is the configuration for data release 8

.. datamodel:: tree.tree:Tree
   :prog: dr8
   :title: dr8
   :remove-sasbase:


.. _sdss5:

SDSS-V
------

This is the temporary, development, configuration for SDSS-V

.. datamodel:: tree.tree:Tree
   :prog: sdss5
   :title: sdss5
   :remove-sasbase: